/*
  Copyright 2019 Kakao Corp.

  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
  You may obtain a copy of the License at

     http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
 */
package com.kakao.sdk.partner.model

import android.os.Parcelable
import com.kakao.sdk.user.model.AgeRange
import com.kakao.sdk.user.model.Gender
import com.kakao.sdk.user.model.Profile
import kotlinx.android.parcel.Parcelize
import java.util.*

/**
 * 사용자 정보 조회 API 응답으로 제공되는 사용자 정보 최상위 클래스입니다. 보다 자세한 내용은 Open SDK 용 User 문서를 참고해주세요.
 *
 * @property hasSignedUp 사용자가 앱에 연결되어 있는지 여부를 나타냅니다. **자동 연결** 설정이 활성화되어 있는 경우 값이 내려오지 않으므로 앱에 연결되어 있다고 가정해도 무방합니다.
 * @property forPartner 파트너용 사용자 정보
 *
 * @author kevin.kang. Created on 2019-10-17..
 *
 * @since 2.0.0
 */
@Parcelize
data class PartnerUser(
    val id: Long,
    val properties: Map<String, String>?,
    val kakaoAccount: PartnerAccount?,
    val groupUserToken: String?,
    val hasSignedUp: Boolean?,
    val forPartner: Map<String, String>?
) : Parcelable

/**
 * 카카오계정에 등록된 사용자 개인정보를 제공합니다.
 *
 * @property profileNeedsAgreement profile 제공에 대한 사용자 동의 필요 여부


 * @property profile
 * @property emailNeedsAgreement
 * @property isEmailValid
 * @property isEmailVerified
 * @property birthyearNeedsAgreement
 * @property birthyear
 * @property birthdayNeedsAgreement
 * @property birthday
 *
 * @since 2.0.0
 */
@Parcelize
data class PartnerAccount(
    val profileNeedsAgreement: Boolean?,
    val profile: Profile?,

    val emailNeedsAgreement: Boolean?,
    val isEmailValid: Boolean?,
    val isEmailVerified: Boolean?,
    val email: String?,

    val ageRangeNeedsAgreement: Boolean?,
    val ageRange: AgeRange?,

    val birthyearNeedsAgreement: Boolean?,
    val birthyear: String?,

    val birthdayNeedsAgreement: Boolean?,
    val birthday: String?,

    val genderNeedsAgreement: Boolean?,
    val gender: Gender?,

    val ciNeedsAgreement: Boolean?,
    val ci: String?,
    val ciAuthenticatedAt: Date?,

    val legalNameNeedsAgreement: Boolean?,
    val legalName: String?,

    val legalBirthDateNeedsAgreement: Boolean?,
    val legalBirthDate: String?,

    val legalGenderNeedsAgreement: Boolean?,
    val legalGender: Gender?,

    val phoneNumberNeedsAgreement: Boolean?,
    val phoneNumber: String?,

    val isKakaotalkUser: Boolean?,
    val displayId: String?
) : Parcelable

/**
 * 파트너용으로 제공되는 추가 정보입니다.
 *
 * @property uuid 메시지를 전송하기 위한 고유 아이디
 * @property remainingInviteCount 남아 있는 초대 메시지 전송 가능 횟수
 * @property remainingGroupMsgCount 남아있는 그룹 메시지 전송 가능 횟수
 *
 * @since 2.0.0
 */
@Parcelize
data class ForPartner(
    val uuid: String?,
    val remainingInviteCount: Int?,
    val remainingGroupMsgCount: Int?
) : Parcelable